==> phoenix-tephra-0.16.0-src.tar.gz: phoenix-tephra-0.16.0/CHANGES.md <==

<!---
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
-->
# TEPHRA Changelog

## Release 0.16.0 - Unreleased (as of 2020-11-16)



### NEW FEATURES:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-301](https://issues.apache.org/jira/browse/TEPHRA-301) | Support HBase 1.5.x |  Major | . |
| [TEPHRA-309](https://issues.apache.org/jira/browse/TEPHRA-309) | Add HBase 1.6 compatibility |  Blocker | . |
| [TEPHRA-307](https://issues.apache.org/jira/browse/TEPHRA-307) | Support Hbase 2.3 |  Major | . |
| [TEPHRA-305](https://issues.apache.org/jira/browse/TEPHRA-305) | Support HBase 2.1 and 2.2 |  Blocker | . |


### IMPROVEMENTS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-314](https://issues.apache.org/jira/browse/TEPHRA-314) | Clean up lib dir in distribution assembly |  Major | . |
| [TEPHRA-310](https://issues.apache.org/jira/browse/TEPHRA-310) | Add OWASP dependency check, and update the flagged direct dependencies |  Major | . |
| [TEPHRA-308](https://issues.apache.org/jira/browse/TEPHRA-308) | create artifact with shaded Guava and Twill in Tephra |  Major | . |
| [TEPHRA-304](https://issues.apache.org/jira/browse/TEPHRA-304) | Remove Support for Java 7 |  Major | . |


### BUG FIXES:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-302](https://issues.apache.org/jira/browse/TEPHRA-302) | Add tests and examples for HBase 1.5.x |  Blocker | . |
| [TEPHRA-312](https://issues.apache.org/jira/browse/TEPHRA-312) | Revert TEPHRA-304 |  Blocker | core |
| [TEPHRA-303](https://issues.apache.org/jira/browse/TEPHRA-303) | HBase 1.1 tests don't compile |  Major | . |
| [TEPHRA-299](https://issues.apache.org/jira/browse/TEPHRA-299) | Executing a large batch delete is very slow |  Major | . |
| [TEPHRA-300](https://issues.apache.org/jira/browse/TEPHRA-300) | Tephra coprocessors do not close passed scanner |  Major | . |

==> phoenix-tephra-0.16.1-src.tar.gz: phoenix-tephra-0.16.1/CHANGES.md <==

<!---
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
-->
# TEPHRA Changelog

## Release 0.16.1 - Unreleased (as of 2021-05-04)



### BUG FIXES:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-316](https://issues.apache.org/jira/browse/TEPHRA-316) | Fix missing executable permission because of MASSEMBLY-941 |  Major | . |


### OTHER:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-317](https://issues.apache.org/jira/browse/TEPHRA-317) | Add support for HBase 2.4 |  Major | core |



## Release 0.16.0 - Unreleased (as of 2020-11-16)



### NEW FEATURES:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-301](https://issues.apache.org/jira/browse/TEPHRA-301) | Support HBase 1.5.x |  Major | . |
| [TEPHRA-309](https://issues.apache.org/jira/browse/TEPHRA-309) | Add HBase 1.6 compatibility |  Blocker | . |
| [TEPHRA-307](https://issues.apache.org/jira/browse/TEPHRA-307) | Support Hbase 2.3 |  Major | . |
| [TEPHRA-305](https://issues.apache.org/jira/browse/TEPHRA-305) | Support HBase 2.1 and 2.2 |  Blocker | . |


### IMPROVEMENTS:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-314](https://issues.apache.org/jira/browse/TEPHRA-314) | Clean up lib dir in distribution assembly |  Major | . |
| [TEPHRA-310](https://issues.apache.org/jira/browse/TEPHRA-310) | Add OWASP dependency check, and update the flagged direct dependencies |  Major | . |
| [TEPHRA-308](https://issues.apache.org/jira/browse/TEPHRA-308) | create artifact with shaded Guava and Twill in Tephra |  Major | . |
| [TEPHRA-304](https://issues.apache.org/jira/browse/TEPHRA-304) | Remove Support for Java 7 |  Major | . |


### BUG FIXES:

| JIRA | Summary | Priority | Component |
|:---- |:---- | :--- |:---- |
| [TEPHRA-302](https://issues.apache.org/jira/browse/TEPHRA-302) | Add tests and examples for HBase 1.5.x |  Blocker | . |
| [TEPHRA-312](https://issues.apache.org/jira/browse/TEPHRA-312) | Revert TEPHRA-304 |  Blocker | core |
| [TEPHRA-303](https://issues.apache.org/jira/browse/TEPHRA-303) | HBase 1.1 tests don't compile |  Major | . |
| [TEPHRA-299](https://issues.apache.org/jira/browse/TEPHRA-299) | Executing a large batch delete is very slow |  Major | . |
| [TEPHRA-300](https://issues.apache.org/jira/browse/TEPHRA-300) | Tephra coprocessors do not close passed scanner |  Major | . |
